@@ -21,6 +21,7 @@
 #include "types.h"
 #include "res.h"
 #include "modules.h"
+#include <linux/vzcalluser.h>
 
 /** Shutdown timeout.
  */
@@ -104,6 +105,26 @@ int vz_chroot(const char *root);
 int vz_env_create(vps_handler *h, envid_t veid, vps_res *res,
 	int wait_p[2], int old_wait_p[2], int err_p[2],
 				env_create_FN fn, void *data);
-int vz_setluid(envid_t veid);
-int vz_env_create_ioctl(vps_handler *h, envid_t veid, int flags);
+
+struct vps_res;
+struct arg_start {
+	struct vps_res *res;
+	int wait_p;
+	int old_wait_p;
+	int err_p;
+	envid_t veid;
+	vps_handler *h;
+	void *data;
+	env_create_FN fn;
+};
+
+struct env_create_param3;
+void fill_container_param(struct arg_start *arg,
+			  struct env_create_param3 *create_param);
+int exec_container_init(struct arg_start *arg,
+			struct env_create_param3 *create_param);
+
+int set_personality32();
+int vz_do_open(vps_handler *h);
+int ct_do_open(vps_handler *h);
 #endif
