@@ -18,12 +18,11 @@
 #ifndef	_TYPES_H_
 #define	_TYPES_H_
 
-#define VZ_DIR			PKGCONFDIR "/"
-#define GLOBAL_CFG		VZ_DIR "vz.conf"
-#define OSRELEASE_CFG		VZ_DIR "osrelease.conf"
-#define VPS_CONF_DIR		VZ_DIR "conf/"
-#define DIST_DIR		VZ_DIR "dists"
-#define VENAME_DIR		VZ_DIR "names"
+#define GLOBAL_CFG		PKGCONFDIR "/vz.conf"
+#define OSRELEASE_CFG		PKGCONFDIR "/osrelease.conf"
+#define VPS_CONF_DIR		PKGCONFDIR "/conf/"
+#define DIST_DIR		PKGCONFDIR "/dists"
+#define VENAME_DIR		PKGCONFDIR "/names"
 
 #define VZCTLDEV		"/dev/vzctl"
 
@@ -59,7 +58,7 @@ typedef unsigned envid_t;
 #define ENV_PATH	"PATH=" DEF_PATH
 
 /* Defaults for checkpointing */
-#define DEF_DUMPDIR	"/vz/dump"
+#define DEF_DUMPDIR	VZDIR "/dump"
 #define DEF_DUMPFILE	"Dump.%d"
 
 /* CT states */
@@ -120,6 +119,7 @@ typedef enum {
 	SKIP_CONFIGURE =	(1<<1),
 	SKIP_ACTION_SCRIPT =	(1<<2),
 	SKIP_UMOUNT =		(1<<3),
+	SKIP_REMOUNT =		(1<<4),
 } skipFlags;
 
 typedef int (* execFn)(void *data);
