@@ -556,15 +556,18 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	free(dist_name);
 	if (ret)
 		return ret;
-	logger(0, 0, "Starting container ...");
-	/* if CT is mounted -- umount first, to cleanup mount state */
-	if (vps_is_mounted(res->fs.root, res->fs.private)) {
-		vps_umount(h, veid, &res->fs, skip);
-	}
+
+	if (!(skip & SKIP_REMOUNT)) {
+		/* if CT is mounted -- umount first, to cleanup mount state */
+		if (vps_is_mounted(res->fs.root, res->fs.private)) {
+			vps_umount(h, veid, &res->fs, skip);
+		}
 #ifdef HAVE_PLOOP
-	else if (ploop && (is_image_mounted(res->fs.private)))
-		vzctl_umount_image(res->fs.private);
+		else if (ploop && (is_image_mounted(res->fs.private)))
+			vzctl_umount_image(res->fs.private);
 #endif
+	}
+
 	if (!vps_is_mounted(res->fs.root, res->fs.private)) {
 		/* increase quota to perform setup */
 		if (!ploop)
@@ -637,8 +640,9 @@ err:
 	free_dist_actions(&actions);
 	if (ret) {
 		/* Kill environment */
-		logger(-1, 0, "Container start failed (try to check kernel "
-				"messages, e.g. \"dmesg | tail\")");
+		logger(-1, 0, "Container %s failed (try to check kernel "
+				"messages, e.g. \"dmesg | tail\")",
+				(fn) ? "restore" : "start");
 		/* Close wait fd without writing anything to it
 		 * to signal the child that we have failed to configure
 		 * the environment, so it should not start /sbin/init
@@ -669,7 +673,8 @@ err:
 			if (ret == VZ_FS_BAD_TMPL)
 				logger(-1, 0, "Unable to start init, probably"
 					" incorrect template");
-			logger(-1, 0, "Container start failed");
+			logger(-1, 0, "Container %s failed",
+					(fn) ? "restore" : "start");
 		}
 	}
 	if (ret) {
@@ -678,7 +683,8 @@ err:
 		/* restore original quota values */
 		if (!ploop)
 			vps_set_quota(veid, &res->dq);
-		if (vps_is_mounted(res->fs.root, res->fs.private))
+		if (vps_is_mounted(res->fs.root, res->fs.private) &&
+				!(skip & SKIP_UMOUNT))
 			vps_umount(h, veid, &res->fs, skip);
 	}
 	close(wait_p[0]);
@@ -701,6 +707,7 @@ err:
 int vps_start(vps_handler *h, envid_t veid, vps_param *param,
 	skipFlags skip, struct mod_action *mod)
 {
+	logger(0, 0, "Starting container...");
 	return vps_start_custom(h, veid, param, skip, mod, NULL, NULL);
 }
 
