@@ -159,6 +159,47 @@ int make_dir(const char *path, int full)
 	return make_dir_mode(path, full, 0755);
 }
 
+char *get_fs_root(const char *dir)
+{
+	struct stat st;
+	dev_t id;
+	size_t len;
+	const char *p, *prev;
+	char tmp[PATH_MAX];
+
+	if (stat(dir, &st) < 0)
+		return NULL;
+	id = st.st_dev;
+	len = strlen(dir);
+	if (len > sizeof(tmp) - 1) {
+		errno = ERANGE;
+		return NULL;
+	}
+	p = dir + len;
+	prev = p;
+	while (p > dir) {
+		while (p > dir && *p == '/') p--;
+		while (p > dir && *p != '/') p--;
+		if (p <= dir)
+			break;
+		len = p - dir + 1;
+		strncpy(tmp, dir, len);
+		tmp[len] = 0;
+		if (stat(tmp, &st) < 0)
+			return NULL;
+		if (id != st.st_dev)
+			break;
+		prev = p;
+	}
+	len = prev - dir;
+	if (len) {
+		strncpy(tmp, dir, len);
+		tmp[len] = 0;
+		return strdup(tmp);
+	}
+	return NULL;
+}
+
 int parse_int(const char *str, int *val)
 {
 	char *tail;
@@ -211,7 +252,7 @@ int cp_file(char *dst, char *src)
 		logger(-1, errno, "Unable to open %s", src);
 		return -1;
 	}
-	if ((fd_dst = open(dst, O_CREAT|O_RDWR, st.st_mode)) < 0) {
+	if ((fd_dst = open(dst, O_CREAT|O_TRUNC|O_RDWR, st.st_mode)) < 0) {
 		logger(-1, errno, "Unable to open %s", dst);
 		close(fd_src);
 		return -1;
